@@ -1,14 +1,14 @@
 
 /**
- *  \file agInit.c
+ * @file agInit.c
  *
  *  Do all the initialization stuff.  For daemon mode, only
  *  children will return.
  *
- *  Time-stamp:      "2010-08-06 08:56:26 bkorb"
+ *  Time-stamp:      "2011-08-22 07:59:15 bkorb"
  *
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
+ *  Copyright (c) 1992-2011 Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -63,16 +63,16 @@ initialize(int arg_ct, char** arg_vec)
     pzLastScheme = zSchemeInit;
     ag_scm_c_eval_string_from_file_line(
         zSchemeInit, SCHEME_INIT_FILE, schemeLine);
-#ifndef scm_t_port
+
     SCM_EVAL_CONST("(add-hook! before-error-hook error-source-line)\n"
                    "(use-modules (ice-9 stack-catch))");
-#endif
 
     pzLastScheme = NULL;
     procState = PROC_STATE_OPTIONS;
     add_env_vars();
 
     doOptions(arg_ct, arg_vec);
+    exit_code = AUTOGEN_EXIT_LOAD_ERROR;
 
     if (OPT_VALUE_TRACE > TRACE_NOTHING)
         SCM_EVAL_CONST("(debug-enable 'backtrace)");
@@ -155,15 +155,15 @@ dep_usage(char const * fmt, ...)
         va_end(ap);
     }
 
-    fprintf(stderr, "invalid make dependency option:  %s", msg);
-    USAGE(EXIT_FAILURE);
+    usage_message("invalid make dependency option:  %s", msg);
+    /* NOTREACHED */
 }
 
 /**
  * Configure dependency option
  */
 LOCAL void
-config_dep(tOptions* pOptions, tOptDesc* pOptDesc)
+config_dep(tOptions * pOptions, tOptDesc * pOptDesc)
 {
     static char const dup_targ[] = "duplicate make target";
 
@@ -180,15 +180,15 @@ config_dep(tOptions* pOptions, tOptDesc* pOptDesc)
 retry:
 
     switch (*popt) {
-    case ' ': case '\t': case '\r': case '\n':
-        while (isspace((int)*(++popt)))  ;
+    case ' ': case TAB: case '\r': case NL:
+        while (IS_WHITESPACE_CHAR((int)*(++popt)))  ;
         goto retry;
 
     case 'Q':
         if (pzDepTarget != NULL)
             dep_usage(dup_targ);
 
-        while (isspace((int)*(++popt)))  ;
+        while (IS_WHITESPACE_CHAR((int)*(++popt)))  ;
         pzDepTarget = make_quote_str(popt);
         break;
 
@@ -196,7 +196,7 @@ retry:
         if (pzDepTarget != NULL)
             dep_usage(dup_targ);
 
-        while (isspace((int)*(++popt)))  ;
+        while (IS_WHITESPACE_CHAR((int)*(++popt)))  ;
         AGDUPSTR(pzDepTarget, popt, "make target name");
         break;
 
@@ -213,7 +213,7 @@ retry:
         if (pzDepFile != NULL)
             dep_usage(dup_targ);
 
-        while (isspace((int)*(++popt)))  ;
+        while (IS_WHITESPACE_CHAR((int)*(++popt)))  ;
         pzDepFile = aprf("%s-XXXXXX", popt);
         break;
 
