@@ -1,8 +1,8 @@
 
-/*
- *  \file autogen.h
+/**
+ * @file autogen.h
  *
- *  Time-stamp:        "2011-04-20 14:25:17 bkorb"
+ *  Time-stamp:        "2011-06-03 12:20:50 bkorb"
  *
  *  Global header file for AutoGen
  *
@@ -30,10 +30,10 @@
 
 #include REGEX_HEADER
 #include <libguile/scmconfig.h>
-#if GUILE_VERSION >= 109000
-# include <libguile.h>
-#else
+#if GUILE_VERSION < 107000
 # include <guile/gh.h>
+#else
+# include <libguile.h>
 #endif
 
 #include "opts.h"
@@ -490,8 +490,6 @@ extern FILE * ag_fmemopen(void *buf, ssize_t len, char const *mode);
 extern int    ag_fmemioctl(FILE * fp, int req, ...);
 #endif
 
-#include "proto.h"
-
 typedef union {
     const void*  cp;
     void*        p;
@@ -521,11 +519,54 @@ MODE v2c_t p2p VALUE( { NULL } );
 # define manageAllocatedData(_ptr)
 #endif
 
+#if __STDC_VERSION__ < 199901L
+# if __GNUC__ >= 2
+#  define __func__ __FUNCTION__
+# else
+#  define __func__ "<unknown>"
+# endif
+#endif
+
 /*
  *  Code variations based on the version of Guile:
  */
 #include "guile-iface.h"
 
+#include "proto.h"
+
+static inline SCM ag_eval(char const * pzStr)
+{
+    SCM res;
+    char const * pzSaveScheme = pzLastScheme; /* Watch for nested calls */
+    pzLastScheme = pzStr;
+
+    res = ag_scm_c_eval_string_from_file_line(
+        pzStr, pCurTemplate->pzTplFile, pCurMacro->lineNo);
+
+    pzLastScheme = pzSaveScheme;
+    return res;
+}
+
+/*
+ *  Extracted from guile-iface stuff.  Seems to be stable since for at least
+ *  1.6.0 through 2.0.0.  1.4.x is thoroughly dead now (May, 2011).
+ */
+#define AG_SCM_DISPLAY(_s) \
+    scm_display(_s, scm_current_output_port())
+
+#define AG_SCM_BOOT_GUILE(_ac, _av, _im) \
+    scm_boot_guile((_ac), (_av), (_im), NULL)
+
+#define AG_SCM_APPLY2(_op, _f, _tst) \
+    scm_apply(_op, _f, scm_cons(_tst, AG_SCM_LISTOFNULL()))
+
+#define AG_SCM_CHAR_P(_c)            SCM_CHARP(_c)
+
+/*
+ * Hide dummy functions from complexity measurement tools
+ */
+#define HIDE_FN(_t)  _t
+
 #endif /* AUTOGEN_BUILD */
 /*
  * Local Variables:
