@@ -2,7 +2,7 @@
 /**
  * @file expString.c
  *
- *  Time-stamp:        "2011-05-31 16:34:42 bkorb"
+ *  Time-stamp:        "2011-08-02 12:21:12 bkorb"
  *
  *  This module implements expression functions that
  *  manipulate string values.
@@ -709,7 +709,7 @@ ag_scm_shell(SCM cmd)
     if (! AG_SCM_STRING_P(cmd))
         return SCM_UNDEFINED;
     {
-        char* pz = runShell(ag_scm2zchars(cmd, "command"));
+        char* pz = shell_cmd(ag_scm2zchars(cmd, "command"));
         cmd   = AG_SCM_STR02SCM(pz);
         AGFREE((void*)pz);
         return cmd;
@@ -742,7 +742,7 @@ ag_scm_shellf(SCM fmt, SCM alist)
     pz  = ag_scm2zchars(fmt, "format");
     fmt = run_printf(pz, len, alist);
 
-    pz  = runShell(ag_scm2zchars(fmt, "shell script"));
+    pz  = shell_cmd(ag_scm2zchars(fmt, "shell script"));
     fmt = AG_SCM_STR02SCM(pz);
     AGFREE((void*)pz);
     return fmt;
@@ -1134,13 +1134,13 @@ ag_scm_string_tr(SCM Str, SCM From, SCM To)
  *
  * doc: @code{match} and  @code{repl} may be either a single string or
  *      a list of strings.  Either way, they must have the same structure
- *      and number of elements.  For example, to replace all less than
- *      and all greater than characters, do something like this:
+ *      and number of elements.  For example, to replace all amphersands,
+ *      less than and greater than characters, do something like this:
  *
  * @example
  *      (string-substitute source
- *      ("&"     "<"    ">")
- *      ("&amp;" "&lt;" "&gt;"))
+ *          (list "&"     "<"    ">")
+ *          (list "&amp;" "&lt;" "&gt;"))
  * @end example
 =*/
 SCM
