@@ -1,13 +1,13 @@
 
 /**
- * \file funcEval.c
+ * @file funcEval.c
  *
  *  This module evaluates macro expressions.
  *
- *  Time-stamp:        "2010-07-16 17:22:47 bkorb"
+ *  Time-stamp:        "2011-05-05 11:02:50 bkorb"
  *
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -34,15 +34,15 @@ static int
 exprType(char* pz);
 /* = = = END-STATIC-FORWARD = = = */
 
-LOCAL tCC*
+LOCAL char const *
 resolveSCM(SCM s)
 {
-    static char z[48];
-    tCC*  pzRes = z;
+    static char  z[48];
+    char const * pzRes = z;
 
-    switch (gh_type_e(s)) {
+    switch (ag_scm_type_e(s)) {
     case GH_TYPE_BOOLEAN:
-        z[0] = SCM_NFALSEP(s) ? '1' : '0'; z[1] = NUL;
+        z[0] = AG_SCM_NFALSEP(s) ? '1' : '0'; z[1] = NUL;
         break;
 
     case GH_TYPE_STRING:
@@ -51,7 +51,7 @@ resolveSCM(SCM s)
         break;
 
     case GH_TYPE_CHAR:
-        z[0] = gh_scm2char(s); z[1] = NUL; break;
+        z[0] = AG_SCM_CHAR(s); z[1] = NUL; break;
 
     case GH_TYPE_VECTOR:
         pzRes = "** Vector **"; break;
@@ -60,7 +60,7 @@ resolveSCM(SCM s)
         pzRes = "** Pair **"; break;
 
     case GH_TYPE_NUMBER:
-        snprintf(z, sizeof(z), "%ld", gh_scm2ulong(s)); break;
+        snprintf(z, sizeof(z), "%ld", AG_SCM_TO_ULONG(s)); break;
 
     case GH_TYPE_PROCEDURE:
 #ifdef SCM_SUBR_ENTRY
@@ -125,15 +125,15 @@ tpl_warning(tTemplate * tpl, tMacro * mac, char const * msg)
  *  Select_Match_NonExistence code to distinguish non-existence from
  *  an empty string value.
  */
-LOCAL tCC*
+LOCAL char const *
 evalExpression(ag_bool* pMustFree)
 {
-    tTemplate*  pT      = pCurTemplate;
-    tMacro*     pMac    = pCurMacro;
-    ag_bool     isIndexed;
-    tDefEntry*  pDef;
-    int         code    = pMac->res;
-    tCC*        pzText  = NULL; /* warning patrol */
+    tTemplate *   pT      = pCurTemplate;
+    tMacro *      pMac    = pCurMacro;
+    ag_bool       isIndexed;
+    tDefEntry *   pDef;
+    int           code    = pMac->res;
+    char const *  pzText  = NULL; /* warning patrol */
 
     *pMustFree = AG_FALSE;
 
@@ -188,7 +188,8 @@ evalExpression(ag_bool* pMustFree)
          *  OTHERWISE, we found an entry.  Make sure we were supposed to.
          */
         else {
-            tSCC zBlock[] = "attempted to use block macro in eval expression";
+            static char const zBlock[] =
+                "attempted to use block macro in eval expression";
 
             if ((code & EMIT_IF_ABSENT) != 0)
                 return (char*)zNil;
@@ -271,7 +272,7 @@ evalExpression(ag_bool* pMustFree)
 
     case EMIT_SHELL:
     {
-        char* pz = runShell(pzText);
+        char* pz = shell_cmd(pzText);
 
         if (*pMustFree)
             AGFREE((void*)pzText);
@@ -307,7 +308,9 @@ evalExpression(ag_bool* pMustFree)
 SCM
 ag_scm_error_source_line(void)
 {
-    tSCC zErr[] = "\nGuile/Scheme evaluation error in %s line %d:  %s\n";
+    static char const zErr[] =
+        "\nGuile/Scheme evaluation error in %s line %d:  %s\n";
+
     fprintf(stderr, zErr, pCurTemplate->pzTplName, pCurMacro->lineNo,
             pCurTemplate->pzTemplText + pCurMacro->ozText);
     fflush(stderr);
@@ -320,7 +323,6 @@ ag_scm_error_source_line(void)
 /*=gfunc emit
  *
  * what: emit the text for each argument
- * general_use:
  *
  * exparg: alist, list of arguments to stringify and emit, , list
  *
@@ -345,12 +347,13 @@ ag_scm_emit(SCM val)
             break;
 
         pSaveFp = pCurFp;
-        pnum    = gh_scm2ulong(val);
+        pnum    = AG_SCM_TO_ULONG(val);
 
         for (; pnum > 0; pnum--) {
             pSaveFp = pSaveFp->pPrev;
             if (pSaveFp == NULL)
-                AG_ABEND(aprf("invalid emission port: %d", gh_scm2ulong(val)));
+                AG_ABEND(aprf("invalid emission port: %d",
+                              AG_SCM_TO_ULONG(val)));
         }
 
         fp = pSaveFp->pFile;
@@ -367,7 +370,7 @@ ag_scm_emit(SCM val)
         if (val == SCM_UNDEFINED)
             break;
 
-        if (SCM_NULLP(val))
+        if (AG_SCM_NULLP(val))
             break;
 
         if (AG_SCM_STRING_P(val)) {
@@ -376,7 +379,7 @@ ag_scm_emit(SCM val)
             break;
         }
 
-        switch (gh_type_e(val)) {
+        switch (ag_scm_type_e(val)) {
         case GH_TYPE_LIST:
         case GH_TYPE_PAIR:
             ag_scm_emit(SCM_CAR(val));
@@ -424,7 +427,7 @@ eval(char const* pzExpr)
     case '`':
         AGDUPSTR(pzTemp, pzExpr, "shell script");
         (void)spanQuote(pzTemp);
-        pzExpr = runShell(pzTemp);
+        pzExpr = shell_cmd(pzTemp);
         AGFREE((void*)pzTemp);
         res = AG_SCM_STR02SCM((char*)pzExpr);
         AGFREE((void*)pzExpr);
@@ -467,10 +470,13 @@ tMacro*
 mFunc_Expr(tTemplate* pT, tMacro* pMac)
 {
     ag_bool needFree;
-    tCC* pz = evalExpression(&needFree);
+    char const * pz = evalExpression(&needFree);
+
+    if (*pz != NUL) {
+        fputs(pz, pCurFp->pFile);
+        fflush(pCurFp->pFile);
+    }
 
-    fputs(pz, pCurFp->pFile);
-    fflush(pCurFp->pFile);
     if (needFree)
         AGFREE((void*)pz);
 
@@ -505,13 +511,13 @@ exprType(char* pz)
  *  mLoad_Expression
  */
 tMacro*
-mLoad_Expr(tTemplate* pT, tMacro* pMac, tCC** ppzScan)
+mLoad_Expr(tTemplate* pT, tMacro* pMac, char const ** ppzScan)
 {
-    char*    pzCopy; /* next text dest   */
-    tCC*     pzSrc  = (char const*)pMac->ozText; /* macro text */
-    size_t   srcLen = (long)pMac->res;           /* macro len  */
-    tCC*     pzSrcEnd = pzSrc + srcLen;
-    tMacro*  pNextMac;
+    char *        pzCopy; /* next text dest   */
+    char const *  pzSrc    = (char const*)pMac->ozText; /* macro text */
+    size_t        srcLen   = (long)pMac->res;           /* macro len  */
+    char const *  pzSrcEnd = pzSrc + srcLen;
+    tMacro *      pNextMac;
 
     switch (*pzSrc) {
     case '-':
