@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Sun Jun 26 07:40:07 PDT 2011
+ * Generated Sun Dec  4 07:09:20 PST 2011
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD 1
@@ -34,7 +34,7 @@ LOCAL void
 close_server_shell(void);
 
 LOCAL char*
-runShell(char const*  pzCmd);
+shell_cmd(char const * pzCmd);
 
 /*
  *  Extracted from agUtils.c
@@ -45,6 +45,9 @@ aprf(char const * pzFmt, ...);
 LOCAL void
 open_trace_file(char ** av, tOptDesc * odsc);
 
+LOCAL void
+check_make_dep_env(void);
+
 LOCAL void
 doOptions(int arg_ct, char ** arg_vec);
 
