@@ -1,10 +1,10 @@
 /*
- *   Character mapping generated 03/07/11 16:35:04
+ *   Character mapping generated 12/04/11 07:08:53
  *
  *  This file contains the character classifications
  *  used by AutoGen and AutoOpts for identifying tokens.
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
+ *  Copyright (c) 1992-2011 Bruce Korb - all rights reserved
  *  AutoGen is free software: you can redistribute it and/or modify it under the
  *  terms of the GNU General Public License as published by the Free Software
  *  Foundation, either version 3 of the License, or (at your option) any later
@@ -70,14 +70,14 @@
 // 
 // %guard          autoopts_internal
 // %file           ag-char-map.h
-// %table          option-char-category
+// %static-table   option-char-category
 // 
 // %comment
 //   This file contains the character classifications
 //   used by AutoGen and AutoOpts for identifying tokens.
 // 
 //   This file is part of AutoGen.
-//   AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
+//   Copyright (c) 1992-2011 Bruce Korb - all rights reserved
 // 
 //   AutoGen is free software: you can redistribute it and/or modify it under the
 //   terms of the GNU General Public License as published by the Free Software
@@ -121,11 +121,11 @@
 #endif /* 0 -- mapping spec. source */
 
 typedef uint32_t option_char_category_mask_t;
-extern option_char_category_mask_t const option_char_category[128];
+static option_char_category_mask_t const option_char_category[128];
 
 static inline int is_option_char_category_char(char ch, option_char_category_mask_t mask) {
     unsigned int ix = (unsigned char)ch;
-    return ((ix < 0x7F) && ((option_char_category[ix] & mask) != 0)); }
+    return ((ix < 128) && ((option_char_category[ix] & mask) != 0)); }
 
 #define IS_LOWER_CASE_CHAR(_c)      is_option_char_category_char((_c), 0x000001)
 #define IS_UPPER_CASE_CHAR(_c)      is_option_char_category_char((_c), 0x000002)
@@ -153,8 +153,8 @@ static inline int is_option_char_category_char(char ch, option_char_category_mas
 #define IS_END_TOKEN_CHAR(_c)       is_option_char_category_char((_c), 0x100500)
 #define IS_END_LIST_ENTRY_CHAR(_c)  is_option_char_category_char((_c), 0x300500)
 
-#ifdef AUTOOPTS_INTERNAL
-option_char_category_mask_t const option_char_category[128] = {
+#if 1 /* def AUTOOPTS_INTERNAL */
+static option_char_category_mask_t const option_char_category[128] = {
   /*x00*/ 0x140000, /*x01*/ 0x000000, /*x02*/ 0x000000, /*x03*/ 0x000000,
   /*x04*/ 0x000000, /*x05*/ 0x000000, /*x06*/ 0x000000, /*\a */ 0x000000,
   /*\b */ 0x000400, /*\t */ 0x000100, /*\n */ 0x000400, /*\v */ 0x000400,
