@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for autoopts
- * Generated Sun Jun 26 07:39:46 PDT 2011
+ * Generated Sun Dec  4 07:09:01 PST 2011
  */
 #ifndef AUTOOPTS_PROTO_H_GUARD
 #define AUTOOPTS_PROTO_H_GUARD 1
@@ -25,13 +25,13 @@ LOCAL char *
 ao_strdup(char const *str);
 
 LOCAL tSuccess
-handle_opt(tOptions* pOpts, tOptState* pOptState);
+handle_opt(tOptions * pOpts, tOptState* pOptState);
 
 LOCAL tSuccess
-doImmediateOpts(tOptions* pOpts);
+immediate_opts(tOptions * pOpts);
 
 LOCAL tSuccess
-doRegularOpts(tOptions* pOpts);
+regular_opts(tOptions * pOpts);
 
 /*
  *  Extracted from check.c
@@ -43,7 +43,7 @@ is_consistent(tOptions * pOpts);
  *  Extracted from configfile.c
  */
 LOCAL void
-internalFileLoad(tOptions* pOpts);
+intern_file_load(tOptions* pOpts);
 
 LOCAL char*
 parseAttributes(
@@ -53,28 +53,31 @@ parseAttributes(
     tOptionValue*       pType );
 
 LOCAL tSuccess
-validateOptionsStruct(tOptions* pOpts, char const* pzProgram);
+validate_struct(tOptions * pOpts, char const * pzProgram);
 
 /*
  *  Extracted from env.c
  */
 LOCAL void
-doPrognameEnv(tOptions* pOpts, teEnvPresetType type);
+doPrognameEnv(tOptions * pOpts, teEnvPresetType type);
 
 LOCAL void
-doEnvPresets(tOptions* pOpts, teEnvPresetType type);
+env_presets(tOptions * pOpts, teEnvPresetType type);
 
 /*
  *  Extracted from find.c
  */
 LOCAL tSuccess
-opt_find_long(tOptions * pOpts, char * opt_name, tOptState * pOptState);
+opt_find_long(tOptions * pOpts, char const * opt_name, tOptState * pOptState);
 
 LOCAL tSuccess
 opt_find_short(tOptions* pOpts, uint_t optValue, tOptState* pOptState);
 
 LOCAL tSuccess
-find_opt(tOptions* pOpts, tOptState* pOptState);
+get_opt_arg(tOptions * pOpts, tOptState * pOptState);
+
+LOCAL tSuccess
+find_opt(tOptions * pOpts, tOptState * pOptState);
 
 /*
  *  Extracted from load.c
